/*

ti pa

30.1 = 1st row cloud

32.1
01.1 = 2-3 row background

31.1 {30.1} 31.1
33.1 {34.1} 35.1 = 2-3 row cloud

01.1 = other row background

33.1 {34.1} 35.1 = other row cloud

3F.2 = frozen grass

3E.2 = frozen tree |

38.2 39.2 3A.2 
3B.2 3C.2 3D.2 = frozen tree leaves

A0.0 A1.0 = pillar surface
68.0 69.0 = pillar

77.0 = horizontal metal bar

A2.0 = vertical metal bar surface
6A.0 = vertical metal bar
6B.0 = vertical metal bar detail

66.0 67.0
6E.0 6F.0
76.0 6F.0 = metal object

E3.3 = water surface
C1.3 = water

2D.3 = inside
2C.3 = inside shadow

24.0 25.0 = plastic pit (background)

*/

static void IcemanAscii(Screen& s)
{
    for(unsigned y=0; y<16; ++y)
        for(unsigned x=0; x<16; ++x)
        {
            unsigned char c = s.outmap[y*16+x].tile;
            unsigned char p = s.outmap[y*16+x].palette;
            
            char ch = '?';
            /* Classify types.
             *
             *
             *
             */
            switch(c)
            {
                // sky:
                case 0x32:
                case 0x01:
                case 0x31: case 0x30:
                case 0x33: case 0x34: case 0x35: // clouds, sky.
                case 0x00: //void
                case 0x3E: case 0x3F:
                case 0x38 ... 0x3A:
                case 0x3B ... 0x3D: // trees and grass
                    ch = '.';
                    break;
                
                case 0xA0: case 0xA1:
                case 0x68: case 0x69:
                case 0xA2: case 0x6A: case 0x6B: // walls
                case 0x51: case 0x52: case 0x53: // wily signature
                    ch = '#';
                    break;
                case 0x77:
                    ch = '=';
                    break;
                case 0x66: case 0x67:
                case 0x6E: case 0x6F:
                case 0x76: // metal object
                    ch = 'M';
                    break;
                case 0x2C: case 0x2D:
                    ch = ' '; // inside
                    break;
                case 0xC1: case 0xE3:
                    ch = '~'; // water
                    break;
                case 0x24: case 0x25:
                    ch = 'V';
                    break;
                    
                case 0x10:
                    ch = Ascii_WilyDoor;
                    break;
                
                // There are no ladders, gutsblock or spikes in Iceman level.
            }
            
            s.ascii[y*32+x] = ch;
            s.ascii[y*32+x+16] = ' ';
            //printf("%02X",c);      
        }
}

#define IcemanChar  DummyChar

static Level Iceman =
{
	1, // level number
	"Iceman",

	// screens:
	{
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "R               "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"............####"   "                "
		"............####"   "           R    "
		"....############"   "                "
		"....############"   "   R            "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"....######......"   "                "
		"....######......"   "   R            "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "               i"
		"~~~~MM~~~~MM~~~~"   "                "
		"~~~~MM~~~~MM~~~~"   "         f      "
		"====MM====MM===="   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~MM~~~~MM~~~~"   "                "
		"~~~~MM~~~~MM~~~~"   "         f      "
		"====MM====MM===="   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~~~~~~~~~~~~~"   "                "
		"~~~~MM~~~~MM~~~~"   "                "
		"~~~~MM~~~~MM~~~~"   "         f      "
		"====MM====MM===="   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"~~~~~~~~~~~~####"   "                "
		"~~~~~~~~~~~~####"   "                "
		"~~~~~~~~########"   "                "
		"~~~~~~~~########"   "       f        "
		"~~~~############"   "                "
		"~~~~############"   "                "
		"====############"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"....######......"   "                "
		"....######......"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "        i       "
		,Right},
		{
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"######  ####VV##"   "                "
		"######  ####VV##"   "                "
		"######  ####VV##"   "                "
		"####      ##VV##"   "                "
		"####      ##VV##"   "    c           "
		"            VV##"   "                "
		"            VV##"   "E c             "
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		,Down},
		{
		"##          VV##"   "                "
		"##          VV##"   "                "
		"##          VV##"   "                "
		"##VV##      VV##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##        ##"   "                "
		"##VV##~~~~~~~~##"   "                "
		"##VV##~~~~~~~~##"   "           f    "
		"##VV############"   "                "
		"##VV############"   "                "
		,Down},
		{
		"##VV##        .."   "                "
		"##VV##        .."   "                "
		"##VV          .."   "                "
		"##VV          .."   "                "
		"##            .."   "                "
		"##            .."   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"####~~~~~~~~~~##"   "                "
		"####~~~~~~~~~~##"   "         f      "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"....######......"   "                "
		"....######......"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "    L           "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "          L    L"
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "         P    L "
		"........##......"   "                "
		"........##......"   "      L         "
		"........##......"   "                "
		"........##......"   "                "
		"........##......"   "                "
		"........##......"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "       i        "
		"................"   "          L     "
		"................"   "               L"
		"................"   "    L           "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		,Right},
		{
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"..............##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		"####        VV##"   "                "
		"####        VV##"   "    U           "
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "i               "
		,Down},
		{
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		"############VV##"   "                "
		"##          VV##"   "                "
		"##          VV##"   "                "
		"##          VV##"   "                "
		"##          VV##"   "   pp pe ee     "
		"############VV##"   "                "
		"############VV##"   "                "
		"##            ##"   "                "
		"##            ##"   "                "
		"##VV############"   "                "
		"##VV############"   "                "
		"##VV############"   "                "
		"##VV############"   "                "
		,Down},
		{
		"##VV            "   "                "
		"##VV            "   "                "
		"##VV            "   "                "
		"##VV            "   "                "
		"##              "   "                "
		"##              "   "                "
		"##              "   "                "
		"##              "   "                "
		"##              "   "                "
		"##              "   "                "
		"##              "   "              t "
		"##              "   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Right},
		{
		"             ###"   "                "
		"             ###"   "                "
		"             ###"   "                "
		"             ###"   "                "
		"             ###"   "                "
		"             ###"   "                "
		"              DD"   "              SS"
		"              DD"   "              SS"
		"              DD"   "              SS"
		"              DD"   "              SS"
		"          ######"   "                "
		"          ######"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,Shutter},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"                "   "X               "
		"                "   "X               "
		"                "   "X               "
		"                "   "X               "
		"################"   "               i"
		"################"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"                "   "                "
		"                "   "                "
		"                "   "                "
		"                "   "                "
		"################"   "                "
		"################"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		,Right},
		{
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"################"   "                "
		"################"   "                "
		"               D"   "               S"
		"               D"   "               S"
		"               D"   "               S"
		"               D"   "               S"
		"################"   "                "
		"################"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "                "
		"................"   "              i "
		,Shutter},
		{
		"################"   "                "
		"################"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"#              #"   "                "
		"               #"   "X               "
		"               #"   "X               "
		"               #"   "X               "
		"               #"   "X               "
		"#              #"   "                "
		"#              #"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		"################"   "                "
		,End},
	},

	// palette
	{
		15, 32, 33, 17, 
		15, 32, 60, 44, 
		15, 32, 33, 44, 
		15, 48,  9, 28, 

		15, 44, 17, 15, 
		15, 32, 56, 15, 
		15, 48, 42, 15, 
		15, 48, 38, 15, 

		15, 32, 33, 17, 
		15, 32, 60, 44, 
		15, 32, 33, 44, 
		15, 48, 16, 32, 
	},

	// actives
	{
		Active( 0, 10, 0x60,0x90, 0x70,0xA0 ),
		Active( 0, 10, 0x80,0x30, 0x90,0x40 ),
		Active( 0, 10, 0x80,0x80, 0x90,0x90 ),
		Active( 0, 10, 0x80,0xB0, 0x90,0xC0 ),
		Active( 0, 10, 0xA0,0x60, 0xB0,0x70 ),
		Active( 0, 10, 0xB0,0xA0, 0xC0,0xB0 ),
		Active( 0, 10, 0xD0,0x80, 0xE0,0x90 ),
		Active( 0, 11, 0x20,0x50, 0x30,0x60 ),
		Active( 0, 11, 0x30,0x90, 0x40,0xA0 ),
		Active( 0, 11, 0x50,0x70, 0x60,0x80 ),
		Active( 0, 11, 0x60,0xA0, 0x70,0xB0 ),
		Active( 0, 11, 0x70,0x30, 0x80,0x40 ),
		Active( 0, 11, 0x70,0x60, 0x80,0x70 ),
		Active( 0, 11, 0x90,0x70, 0xA0,0x80 ),
		Active( 0, 11, 0x90,0xB0, 0xA0,0xC0 ),
		Active( 0, 11, 0xA0,0x90, 0xB0,0xA0 ),
		Active( 0, 11, 0xB0,0x30, 0xC0,0x40 ),
		Active( 0, 11, 0xC0,0xB0, 0xD0,0xC0 ),
	},

	// enemies
	{
		Enemy( 4, 0x80,0x02, 0xFF ),
		Enemy( 4, 0x82,0xFE, 0x1F ),
		Enemy( 8, 0x00,0x00, 0xFF ),
		Enemy( 10, 0xE0,0x80, 0x10 ),
		Enemy( 11, 0xE0,0x80, 0x10 ),
	},

	IcemanAscii, IcemanChar
};



